<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>@default</name>
    <message>
        <source>Speech</source>
        <translation>Speech</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Notifications</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Maximum number of spoken letters</source>
        <translation>Maximum number of spoken letters</translation>
    </message>
    <message>
        <source>Message too long (male)</source>
        <translation>Message too long (male)</translation>
    </message>
    <message>
        <source>Message too long (female)</source>
        <translation>Message too long (female)</translation>
    </message>
    <message>
        <source>Voice</source>
        <translation>Voice</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Frequency</translation>
    </message>
    <message>
        <source>Base frequency</source>
        <translation>Base frequency</translation>
    </message>
    <message>
        <source>Tempo</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <source>Melody</source>
        <translation>Melody</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Sound</translation>
    </message>
    <message>
        <source>Sound system</source>
        <translation>Sound system</translation>
    </message>
    <message>
        <source>aRts</source>
        <translation>aRts</translation>
    </message>
    <message>
        <source>Esd</source>
        <translation>Esd</translation>
    </message>
    <message>
        <source>Dsp</source>
        <translation>Dsp</translation>
    </message>
    <message>
        <source>Dsp device</source>
        <translation>Dsp device</translation>
    </message>
    <message>
        <source>Klatt synthesizer (requires dsp)</source>
        <translation>Klatt synthesizer (requires dsp)</translation>
    </message>
    <message>
        <source>Speech program</source>
        <translation>Speech program</translation>
    </message>
    <message>
        <source>Test</source>
        <translation>Test</translation>
    </message>
    <message>
        <source>Read a text</source>
        <translation>Read a text</translation>
    </message>
</context>
<context>
    <name>SpeechConfigurationWidget</name>
    <message>
        <source>Male format</source>
        <translation>Male format</translation>
    </message>
    <message>
        <source>Female format</source>
        <translation>Female format</translation>
    </message>
</context>
</TS>
